@@ -2,14 +2,28 @@
 
 from sqlfluff.core.parser.segments.base import (
     BaseSegment,
-    FixPatch,
     SourceFix,
     UnparsableSegment,
 )
 from sqlfluff.core.parser.segments.bracketed import BracketedSegment
-from sqlfluff.core.parser.segments.ephemeral import EphemeralSegment, allow_ephemeral
+from sqlfluff.core.parser.segments.common import (
+    BinaryOperatorSegment,
+    CodeSegment,
+    CommentSegment,
+    ComparisonOperatorSegment,
+    CompositeBinaryOperatorSegment,
+    CompositeComparisonOperatorSegment,
+    IdentifierSegment,
+    LiteralSegment,
+    NewlineSegment,
+    SymbolSegment,
+    UnlexableSegment,
+    WhitespaceSegment,
+    WordSegment,
+)
 from sqlfluff.core.parser.segments.file import BaseFileSegment
 from sqlfluff.core.parser.segments.generator import SegmentGenerator
+from sqlfluff.core.parser.segments.keyword import KeywordSegment, LiteralKeywordSegment
 from sqlfluff.core.parser.segments.meta import (
     Dedent,
     EndOfFile,
@@ -19,16 +33,7 @@ from sqlfluff.core.parser.segments.meta import (
     TemplateLoop,
     TemplateSegment,
 )
-from sqlfluff.core.parser.segments.raw import (
-    CodeSegment,
-    CommentSegment,
-    KeywordSegment,
-    NewlineSegment,
-    RawSegment,
-    SymbolSegment,
-    UnlexableSegment,
-    WhitespaceSegment,
-)
+from sqlfluff.core.parser.segments.raw import RawSegment
 
 __all__ = (
     "BaseSegment",
@@ -43,9 +48,8 @@ __all__ = (
     "WhitespaceSegment",
     "NewlineSegment",
     "KeywordSegment",
+    "LiteralKeywordSegment",
     "SymbolSegment",
-    "EphemeralSegment",
-    "allow_ephemeral",
     "MetaSegment",
     "Indent",
     "Dedent",
@@ -53,6 +57,12 @@ __all__ = (
     "TemplateSegment",
     "EndOfFile",
     "TemplateLoop",
-    "FixPatch",
     "SourceFix",
+    "IdentifierSegment",
+    "LiteralSegment",
+    "BinaryOperatorSegment",
+    "CompositeBinaryOperatorSegment",
+    "ComparisonOperatorSegment",
+    "CompositeComparisonOperatorSegment",
+    "WordSegment",
 )
