@@ -1,6 +1,6 @@
 """Templater Code."""
 
-from typing import Iterator, Type
+from collections.abc import Iterator
 
 # Although these shouldn't usually be instantiated from here
 # we import them to make sure they get registered.
@@ -10,9 +10,14 @@ from sqlfluff.core.templaters.placeholder import PlaceholderTemplater
 from sqlfluff.core.templaters.python import PythonTemplater
 
 
-def core_templaters() -> Iterator[Type[RawTemplater]]:
+def core_templaters() -> Iterator[type[RawTemplater]]:
     """Returns the templater tuples for the core templaters."""
-    yield from [RawTemplater, JinjaTemplater, PythonTemplater, PlaceholderTemplater]
+    yield from [
+        RawTemplater,
+        JinjaTemplater,
+        PythonTemplater,
+        PlaceholderTemplater,
+    ]
 
 
 __all__ = (
