@@ -29,6 +29,7 @@ from sqlfluff.core.parser import (
     TypedParser,
 )
 from sqlfluff.dialects import dialect_ansi as ansi
+from sqlfluff.dialects import dialect_trino as trino
 from sqlfluff.dialects.dialect_athena_keywords import (
     athena_reserved_keywords,
     athena_unreserved_keywords,
@@ -214,7 +215,6 @@ athena_dialect.add(
         type="quoted_identifier",
         casefold=str.lower,
     ),
-    DatetimeWithTZSegment=Sequence(OneOf("TIMESTAMP", "TIME"), "WITH", "TIME", "ZONE"),
 )
 
 athena_dialect.replace(
@@ -272,11 +272,40 @@ athena_dialect.replace(
         # UNNEST can optionally have a WITH ORDINALITY clause
         insert=[
             Sequence("WITH", "ORDINALITY", optional=True),
+            Ref("WithinGroupClauseSegment"),
         ]
     ),
+    FunctionContentsGrammar=ansi_dialect.get_grammar("FunctionContentsGrammar").copy(
+        insert=[
+            Ref("ListaggOverflowClauseSegment"),
+        ]
+    ),
+    AlterTableDropColumnGrammar=Sequence(
+        "DROP",
+        Ref.keyword("COLUMN"),
+        Ref("SingleIdentifierGrammar"),
+    ),
 )
 
 
+class WithinGroupClauseSegment(trino.WithinGroupClauseSegment):
+    """An WITHIN GROUP clause for window functions.
+
+    These are based on Trino.
+    https://docs.aws.amazon.com/athena/latest/ug/functions-env3.html
+    https://trino.io/docs/current/functions/aggregate.html#listagg
+    """
+
+
+class ListaggOverflowClauseSegment(trino.ListaggOverflowClauseSegment):
+    """ON OVERFLOW clause of listagg function.
+
+    These are based on Trino.
+    https://docs.aws.amazon.com/athena/latest/ug/functions-env3.html
+    https://trino.io/docs/current/functions/aggregate.html#listagg
+    """
+
+
 class ArrayTypeSegment(ansi.ArrayTypeSegment):
     """Prefix for array literals specifying the type."""
 
@@ -414,7 +443,7 @@ class DatatypeSegment(BaseSegment):
                 )
             ),
         ),
-        Ref("DatetimeWithTZSegment"),
+        Ref("TimeWithTZGrammar"),
     )
 
 
@@ -577,6 +606,15 @@ class RowFormatClauseSegment(BaseSegment):
     )
 
 
+class ValuesClauseSegment(ansi.ValuesClauseSegment):
+    """A `VALUES` clause within in `WITH`, `SELECT`, `INSERT`."""
+
+    match_grammar = Sequence(
+        "VALUES",
+        Delimited(Ref("ExpressionSegment")),
+    )
+
+
 class InsertStatementSegment(BaseSegment):
     """`INSERT INTO` statement.
 
