@@ -177,6 +177,7 @@ UNRESERVED_KEYWORDS = [
     "INF",
     "INJECTIVE",
     "INSERT",
+    "INTERVAL",
     "INTO",
     "IS",
     "IS_OBJECT_ID",
@@ -226,6 +227,7 @@ UNRESERVED_KEYWORDS = [
     "PROFILE",
     "PROJECTION",
     "QUARTER",
+    "QUERY",
     "QUOTA",
     "QUEUES",
     "RANGE",
