@@ -8,6 +8,7 @@ ANALYSE
 ANALYZE
 AND
 ANY
+APPEND
 ARRAY
 AS
 ASC
@@ -182,6 +183,7 @@ ALTER
 ALWAYS
 ANYELEMENT
 APPLY
+APPROXIMATE
 ARE
 ARRAY_AGG
 ARRAY_MAX_CARDINALITY
@@ -196,6 +198,8 @@ ATOMIC
 ATTACH
 ATTRIBUTE
 ATTRIBUTES
+AUTHENTICATION
+AUTHENTICATION_ARN
 AUTO
 AUTO_INCREMENT
 AVG
@@ -381,6 +385,7 @@ DOCUMENT
 DOMAIN
 DOUBLE
 DROP
+DUPLICATES
 DYNAMIC
 DYNAMIC_FUNCTION
 DYNAMIC_FUNCTION_CODE
@@ -424,6 +429,7 @@ FAMILY
 FETCH
 FIELDS
 FILE
+FILLTARGET
 FILTER
 FINAL
 FINALIZE
@@ -476,9 +482,11 @@ HLLSKETCH
 HOLD
 HOUR
 HYPERPARAMETERS
+IAM
 IAM_ROLE
 ID
 IF
+IGNOREEXTRA
 IMMEDIATE
 IMMEDIATELY
 IMMUTABLE
@@ -529,6 +537,7 @@ JSON_TABLE
 JSON_TABLE_PRIMITIVE
 JSON_VALUE
 K
+KAFKA
 KEEP
 KEY
 KEYS
@@ -539,6 +548,7 @@ KMEANS
 KMS_KEY_ID
 LABEL
 LAG
+LAMBDA
 LANGUAGE
 LARGE
 LAST
@@ -616,6 +626,8 @@ MONITOR
 MONTH
 MORE
 MOVE
+MSK
+MTLS
 MULTICLASS_CLASSIFICATION
 MULTISET
 MYSQL
@@ -805,6 +817,7 @@ RESTART
 RESTRICT
 RESTRICTED
 RESULT
+RETRY_TIMEOUT
 RETURN
 RETURNED_CARDINALITY
 RETURNED_LENGTH
@@ -814,6 +827,7 @@ RETURNING
 RETURNS
 REVOKE
 RLIKE
+RLS
 ROLE
 ROLLBACK
 ROLLUP
@@ -1034,6 +1048,7 @@ VARIADIC
 VARYING
 VERSION
 VERSIONING
+VIA
 VIEW
 VIEWS
 VOLATILE
