@@ -9,6 +9,8 @@ AND
 ANY
 AS
 ASOF
+BEARER
+BEARER_TOKEN
 BETWEEN
 BY
 CAST
@@ -21,8 +23,8 @@ CURRENT
 CURRENT_DATE
 CURRENT_TIME
 CURRENT_TIMESTAMP
-CURRENT_USER
 DELETE
+DELTA
 DECLARE
 DISTINCT
 DROP
@@ -36,6 +38,7 @@ GRANT
 GROUP
 GSCLUSTER
 HAVING
+HYBRID
 ILIKE
 IN
 INCREMENT
@@ -99,25 +102,39 @@ ABORT_STATEMENT
 ACCESS
 ACCOUNT
 ACCOUNTS
+ACTION
 ADD
 ADMIN
 AFTER
 AGGREGATE
+AGGREGATION
+ALERT
 ALLOW_DUPLICATE
 ALLOW_OVERLAPPING_EXECUTION
 ALLOW_WRITES
+ALLOWED_AUTHENTICATION_SECRETS
 ALLOWED_IP_LIST
 ALLOWED_NETWORK_RULE_LIST
 ALLOWED_VALUES
 ALWAYS
 API
+API_ALLOWED_PREFIXES
+API_AWS_ROLE_ARN
+API_BLOCKED_PREFIXES
 API_INTEGRATION
+API_KEY
+API_PROVIDER
 APPEND_ONLY
+APPLICATION
 APPLY
 ARRAY
 ASC
+ASYNC
 AT
 ATTACH
+ATTRIBUTES
+AUTHENTICATION
+AUTHENTICATION_METHODS
 AUTHORIZATION
 AUTHORIZATIONS
 AUTO
@@ -129,7 +146,13 @@ AUTO_RESUME
 AUTO_SUSPEND
 AUTOINCREMENT
 AVRO
+AWS_API_GATEWAY
+AWS_GLUE
+AWS_PRIVATE_API_GATEWAY
+AWS_GOV_API_GATEWAY
+AWS_GOV_PRIVATE_API_GATEWAY
 AWS_KEY_ID
+AWS_PRIVATE_API_GATEWAY
 AWS_ROLE
 AWS_SECRET_KEY
 AWS_SNS
@@ -138,12 +161,15 @@ AWS_SNS_TOPIC
 AWS_SNS_TOPIC_ARN
 AWS_TOKEN
 AZURE
+AZURE_API_MANAGEMENT
+AZURE_AD_APPLICATION_ID
 AZURE_EVENT_GRID
 AZURE_EVENT_GRID_TOPIC_ENDPOINT
 AZURE_SAS_TOKEN
 AZURE_STORAGE_QUEUE
 AZURE_STORAGE_QUEUE_PRIMARY_URI
 AZURE_TENANT_ID
+BASE_LOCATION
 BASE64
 BEFORE
 BEGIN
@@ -156,6 +182,7 @@ BLOCK
 BLOCKED_IP_LIST
 BLOCKED_NETWORK_RULE_LIST
 BODY
+BOOLEAN
 BROTLI
 BZ2
 CACHE
@@ -167,10 +194,18 @@ CASE
 CASE_INSENSITIVE
 CASE_SENSITIVE
 CASES
+CATALOG
+CATALOG_API_TYPE
+CATALOG_NAME
+CATALOG_NAMESPACE
+CATALOG_SOURCE
+CATALOG_TABLE_NAME
+CATALOG_URI
 CHAIN
 CHANGE_TRACKING
 CHANGES
 CHARACTER
+CLIENT_TYPES
 CLONE
 CLUSTER
 CLUSTERING
@@ -186,6 +221,7 @@ CONTEXT_HEADERS
 CONTINUE
 COPY
 COPY_OPTIONS
+CORTEX
 CREDENTIALS
 CREDIT_QUOTA
 CROSS
@@ -202,6 +238,7 @@ CURRENT_SCHEMAS
 CURRENT_SESSION
 CURRENT_STATEMENT
 CURRENT_TRANSACTION
+CURRENT_USER
 CURRENT_VERSION
 CURRENT_WAREHOUSE
 CURSOR
@@ -244,10 +281,12 @@ DOWNSTREAM
 DYNAMIC
 ECONOMY
 EMAIL
+EMBEDDING_MODEL
 EMPTY
 EMPTY_FIELD_AS_NULL
 ENABLE
 ENABLE_OCTAL
+ENABLE_QUERY_ACCELERATION
 ENABLED
 ENCODING
 ENCRYPTION
@@ -255,6 +294,7 @@ END
 END_TIMESTAMP
 ENFORCE_LENGTH
 ENFORCED
+ENTITY
 ENUM
 ERROR
 ERROR_INTEGRATION
@@ -273,6 +313,7 @@ EXTENSION
 EXTERNAL
 EXTERNAL_ACCESS_INTEGRATIONS
 EXTERNAL_STAGE
+EXTERNAL_VOLUME
 FATAL
 FETCH
 FIELD_DELIMITER
@@ -301,7 +342,14 @@ GCP_PUBSUB_SUBSCRIPTION_NAME
 GCP_PUBSUB_TOPIC_NAME
 GCS
 GET
+GIT_HTTPS_API
 GLOBAL
+GLUE
+GLUE_AWS_ROLE_ARN
+GLUE_CATALOG_ID
+GLUE_REGION
+GOOGLE_AUDIENCE
+GOOGLE_API_GATEWAY
 GRANTED
 GRANTS
 GROUPING
@@ -311,6 +359,8 @@ HEADER
 HEADERS
 HEX
 HISTORY
+ICEBERG
+ICEBERG_REST
 IDENTIFIER
 IDENTITY
 IF
@@ -326,6 +376,7 @@ INCLUDE
 INCLUDE_METADATA
 INCLUDE_QUERY_ID
 INDEX
+INDEXING
 INFO
 INFORMATION
 INITIALIZE
@@ -351,6 +402,7 @@ LET
 LIMIT
 LIST
 LISTING
+LOAD_UNCERTAIN_FILES
 LOCAL
 LOCATION
 LOCKS
@@ -378,11 +430,14 @@ MAX_SIZE
 MAXVALUE
 MEASURES
 MERGE
+METADATA_FILE_PATH
 METADATA$FILENAME
 METADATA$FILE_ROW_NUMBER
 METADATA$FILE_CONTENT_KEY
 METADATA$FILE_LAST_MODIFIED
 METADATA$START_SCAN_TIME
+MFA_AUTHENTICATION_METHODS
+MFA_ENROLLMENT
 MIDDLE_NAME
 MIN_CLUSTER_COUNT
 MINS_TO_BYPASS_MFA
@@ -390,9 +445,11 @@ MINS_TO_UNLOCK
 MINVALUE
 ML
 MODEL
+MODELS
 MODIFIED_AFTER
 MODIFY
 MONITOR
+MONITORS
 MONTHLY
 MUST_CHANGE_PASSWORD
 NAME
@@ -407,6 +464,8 @@ NOCYCLE
 NONE
 NOORDER
 NORELY
+NOTEBOOK
+NOTEBOOKS
 NOTIFICATION
 NOTIFICATION_INTEGRATION
 NOTIFICATION_PROVIDER
@@ -415,7 +474,13 @@ NOTIFY_USERS
 NOVALIDATE
 NULL_IF
 NULLS
+OAUTH
+OAUTH_ALLOWED_SCOPES
+OAUTH_CLIENT_ID
+OAUTH_CLIENT_SECRET
+OAUTH_TOKEN_URI
 OBJECT
+OBJECT_STORE
 OBJECTS
 OFF
 OFFSET
@@ -427,9 +492,11 @@ ONLY
 OPERATE
 OPTIMIZATION
 OPTION
+OPTIONAL
 OPTIONS
 ORC
 ORGANIZATION
+OTHER
 OUTBOUND
 OUTER
 OVER
@@ -443,7 +510,9 @@ PARALLEL
 PARAMETERS
 PARQUET
 PARSE_HEADER
+PARTIAL
 PARTITION
+PARTITION_TYPE
 PASSWORD
 PASSWORD_HISTORY
 PASSWORD_LOCKOUT_TIME_MINS
@@ -465,6 +534,7 @@ PIPE
 PIPE_EXECUTION_PAUSED
 PIPES
 PIVOT
+POLARIS
 POLICIES
 POLICY
 PRECEDING
@@ -481,6 +551,7 @@ PURGE
 PUT
 PYTHON
 QUERIES
+QUERY_ACCELERATION_MAX_SCALE_FACTOR
 QUERY_WAREHOUSE
 QUEUE
 RANGE
@@ -492,6 +563,7 @@ RECURSIVE
 REFERENCE_USAGE
 REFERENCES
 REFRESH
+REFRESH_INTERVAL_SECONDS
 REFRESH_MODE
 REFRESH_ON_CREATE
 REGIONS
@@ -503,6 +575,8 @@ REPLACE
 REPLACE_INVALID_CHARACTERS
 REPLICATION
 REQUEST_TRANSLATOR
+REQUIRE
+REQUIRED
 RESET
 RESOURCE
 RESOURCE_MONITOR
@@ -510,6 +584,8 @@ RESPECT
 RESPONSE_TRANSLATOR
 RESTRICT
 RESTRICTIONS
+REST_AUTHENTICATION
+REST_CONFIG
 RESULT
 RESULTSET
 RESUME
@@ -542,11 +618,15 @@ SECONDARY
 SECRETS
 SECURE
 SECURITY
+SECURITY_INTEGRATIONS
 SEED
 SEPARATOR
 SEQUENCE
 SEQUENCES
 SERVER
+SERVICE
+SERVICES
+SERVING
 SESSION
 SESSION_USER
 SETS
@@ -555,6 +635,11 @@ SHARE_RESTRICTIONS
 SHARES
 SHOW
 SHOW_INITIAL_ROWS
+SIGV4
+SIGV4_EXTERNAL_ID
+SIGV4_IAM_ROLE
+SIGV4_SIGNING_REGION
+SIMPLE
 SINGLE
 SIZE_LIMIT
 SKIP
@@ -606,6 +691,7 @@ SYSDATE
 SYSTEM
 TABLES
 TABLESPACE
+TABLE_FORMAT
 TABULAR
 TAG
 TARGET_LAG
@@ -621,6 +707,7 @@ TIME
 TIME_FORMAT
 TIMESTAMP
 TIMESTAMP_FORMAT
+TITLE
 TOP
 TRACE
 TRACE_LEVEL
@@ -642,7 +729,11 @@ US
 USAGE
 USE
 USE_ANY_ROLE
+USE_LOGICAL_TYPE
+USE_PRIVATELINK_ENDPOINT
+USE_VECTORIZED_SCANNER
 USER
+USER_SPECIFIED
 USER_TASK_MANAGED_INITIAL_WAREHOUSE_SIZE
 USER_TASK_TIMEOUT_MS
 USERS
